==> estateplat-common-1.2.4-20210315.081213-667-sources.jar: cn/gtmap/estateplat/model/trade/JcptFwxx.java <==
package cn.gtmap.estateplat.model.trade;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;

@Entity
@Table(name = "JCPT_FWXX")
public class JcptFwxx {
    @Id
    private String fwxxid;
    private String ywid;
    private String isfsss;
    private String zh;
    private String fjh;
    private String bdcdyh;
    private String szc;
    private String ghyt;
    private String fwjg;
    private String cg;
    private String dscs;
    private String dxcs;
    private String jzmj;
    private String tnmj;
    private String ftmj;
    private String cqzh;
    private String cqzhjc;
    private String zl;

    public String getFwxxid() {
        return fwxxid;
    }

    public void setFwxxid(String fwxxid) {
        this.fwxxid = fwxxid;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getIsfsss() {
        return isfsss;
    }

    public void setIsfsss(String isfsss) {
        this.isfsss = isfsss;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getCg() {
        return cg;
    }

    public void setCg(String cg) {
        this.cg = cg;
    }

    public String getDscs() {
        return dscs;
    }

    public void setDscs(String dscs) {
        this.dscs = dscs;
    }

    public String getDxcs() {
        return dxcs;
    }

    public void setDxcs(String dxcs) {
        this.dxcs = dxcs;
    }

    public String getJzmj() {
        return jzmj;
    }

    public void setJzmj(String jzmj) {
        this.jzmj = jzmj;
    }

    public String getTnmj() {
        return tnmj;
    }

    public void setTnmj(String tnmj) {
        this.tnmj = tnmj;
    }

    public String getFtmj() {
        return ftmj;
    }

    public void setFtmj(String ftmj) {
        this.ftmj = ftmj;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getCqzhjc() {
        return cqzhjc;
    }

    public void setCqzhjc(String cqzhjc) {
        this.cqzhjc = cqzhjc;
    }
}

==> estateplat-common-1.2.4-20210322.013845-676-sources.jar: cn/gtmap/estateplat/model/trade/JcptFwxx.java <==
package cn.gtmap.estateplat.model.trade;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;

@Entity
@Table(name = "JCPT_FWXX")
public class JcptFwxx {
    @Id
    private String fwxxid;
    private String ywid;
    private String isfsss;
    private String zh;
    private String fjh;
    private String bdcdyh;
    private String szc;
    private String ghyt;
    private String fwjg;
    private String cg;
    private String dscs;
    private String dxcs;
    private String jzmj;
    private String tnmj;
    private String ftmj;
    private String cqzh;
    private String cqzhjc;
    private String zl;
    private String fwbm;

    public String getFwxxid() {
        return fwxxid;
    }

    public void setFwxxid(String fwxxid) {
        this.fwxxid = fwxxid;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getIsfsss() {
        return isfsss;
    }

    public void setIsfsss(String isfsss) {
        this.isfsss = isfsss;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getCg() {
        return cg;
    }

    public void setCg(String cg) {
        this.cg = cg;
    }

    public String getDscs() {
        return dscs;
    }

    public void setDscs(String dscs) {
        this.dscs = dscs;
    }

    public String getDxcs() {
        return dxcs;
    }

    public void setDxcs(String dxcs) {
        this.dxcs = dxcs;
    }

    public String getJzmj() {
        return jzmj;
    }

    public void setJzmj(String jzmj) {
        this.jzmj = jzmj;
    }

    public String getTnmj() {
        return tnmj;
    }

    public void setTnmj(String tnmj) {
        this.tnmj = tnmj;
    }

    public String getFtmj() {
        return ftmj;
    }

    public void setFtmj(String ftmj) {
        this.ftmj = ftmj;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getCqzhjc() {
        return cqzhjc;
    }

    public void setCqzhjc(String cqzhjc) {
        this.cqzhjc = cqzhjc;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }
}
